

ALTER TABLE mortals_xhx_user ADD COLUMN  third_party_user_id VARCHAR(255) DEFAULT NULL COMMENT '第三方平台的用户唯一标识';
ALTER TABLE mortals_xhx_user ADD COLUMN  third_party_token VARCHAR(512) DEFAULT NULL COMMENT '第三方平台用户的认证令牌';

-- ----------------------------
-- 房间表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_room`;
CREATE TABLE `mortals_xhx_room` (
    `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'id',
    `room_name` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL COMMENT '房间名称',
    `room_type` tinyint(2) DEFAULT '1' COMMENT '房间类型(1.单人房间，2.多人房间)',
    `third_party_room_id` varchar(255) DEFAULT '' COMMENT '第三方平台的房间唯一标识',
    `third_party_platform` varchar(64) DEFAULT 'other' COMMENT '第三方平台类型(tencent.腾讯云,aliyun.阿里云,other.其它)',
    `third_party_config` varchar(1024) DEFAULT '' COMMENT '第三方平台的额外配置',
    `start_time` datetime DEFAULT NULL COMMENT '房间开始时间,如直播、会议等',
    `end_time` datetime DEFAULT NULL COMMENT '房间结束时间',
    `locked` tinyint(2) DEFAULT '0' COMMENT '是否被锁定，避免新用户加入(0.否，1.是)',
    `room_status` varchar(32) DEFAULT 'active' COMMENT '房间状态 (active.激活，inactive.非激活，closed.关闭)', -- 房间状态：激活、非激活、关闭
    `create_user_id` bigint(20) DEFAULT NULL COMMENT '创建用户',
    `create_time` datetime DEFAULT NULL COMMENT '创建时间',
    `update_time` datetime DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci ROW_FORMAT=DYNAMIC COMMENT='房间表';



-- ----------------------------
-- 房间成员表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_room_member`;
CREATE TABLE `mortals_xhx_room_member` (
    `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '种类详情id',
    `room_id` bigint(20) DEFAULT NULL COMMENT '房间ID',
    `user_id` bigint(20) DEFAULT NULL COMMENT '用户ID',
    `room_name` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL COMMENT '房间名称',
    `role` varchar(32) DEFAULT 'owner' COMMENT '房间角色(owner.自己，moderator.主持人，participant.参与者)',
    `joined_time` datetime DEFAULT NULL COMMENT '加入时间',
    `leave_time` datetime DEFAULT NULL COMMENT '离开时间',
    `active` tinyint(2) DEFAULT '0' COMMENT '用户是否仍然在房间中(0.离线，1.在线)',
    `create_user_id` bigint(20) DEFAULT NULL COMMENT '创建用户',
    `create_time` datetime DEFAULT NULL COMMENT '创建时间',
    `update_time` datetime DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE,
    UNIQUE KEY `uni_room_user` (`room_id`,`user_id`) USING BTREE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci ROW_FORMAT=DYNAMIC COMMENT='房间成员表';

-- ----------------------------
-- 房间成员表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_room_member`;
CREATE TABLE `mortals_xhx_room_member` (
    `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '种类详情id',
    `room_id` bigint(20) DEFAULT NULL COMMENT '房间ID',
    `audio_enabled` tinyint(2) DEFAULT '1' COMMENT '是否启用音频(0.否，1.是)',
    `video_enabled` tinyint(2) DEFAULT '1' COMMENT '是否启用视频(0.否，1.是)',
    `max_participants` tinyint(2) DEFAULT 10 COMMENT '最大参与人数',
    `third_party_media_config` varchar(1024) DEFAULT NULL COMMENT '第三方音视频平台的特殊配置',
    `third_party_recording_enabled` tinyint(2) DEFAULT '0' COMMENT '是否启用第三方录制服务(0.否，1.是)',
    `create_user_id` bigint(20) DEFAULT NULL COMMENT '创建用户',
    `create_time` datetime DEFAULT NULL COMMENT '创建时间',
    `update_time` datetime DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci ROW_FORMAT=DYNAMIC COMMENT='房间成员表';


-- ----------------------------
-- 音视频流映射表
-- 该表用于存储与第三方音视频组件（如腾讯云）相关的信息，包括流 ID、流类型、状态等。
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_room_video_stream`;
CREATE TABLE `mortals_xhx_room_video_stream` (
   `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '种类详情id',
   `room_id` bigint(20) DEFAULT NULL COMMENT '房间ID',
   `stream_id` varchar(1024) DEFAULT '' COMMENT '流ID，视频流的唯一标识符，腾讯云等平台会分配一个流 ID',
   `stream_url` varchar(1024) DEFAULT '' COMMENT '流的URL,云分配的流地址，客户端需要通过此地址来接入流',
   `stream_type`  varchar(32) DEFAULT 'main' COMMENT '流类型：主流、屏幕共享(main.主流，screen_share.屏幕共享)',
   `status` tinyint(2) DEFAULT '0' COMMENT '流的状态：活跃或非活跃(0.active，1.inactive)',
   `create_user_id` bigint(20) DEFAULT NULL COMMENT '创建用户',
   `end_time` datetime DEFAULT NULL COMMENT '流的结束时间',
   `create_time` datetime DEFAULT NULL COMMENT '创建时间',
   `update_time` datetime DEFAULT NULL COMMENT '更新时间',
   PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci ROW_FORMAT=DYNAMIC COMMENT='音视频流映射表';


-- ----------------------------
-- 房间消息表
-- 该表用于存储房间内的实时消息或信令信息。可以用于处理聊天室内的文字消息或其他类型的实时消息。
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_room_message`;
CREATE TABLE `mortals_xhx_room_message` (
   `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '种类详情id',
   `room_id` bigint(20) DEFAULT NULL COMMENT '房间ID',
   `sender_id` bigint(20) DEFAULT NULL COMMENT '发送者用户ID',
   `message_type` varchar(32) DEFAULT 'text' COMMENT '消息类型，可以支持多种类型的消息，例如文字、图片、文件等(text.文本，audio.音频，video.视频，image.图片，file.文件)',
   `content` text DEFAULT NULL COMMENT '消息内容，存储实际的消息内容，可以是文本、图片路径、文件地址等',
   `send_time` datetime DEFAULT NULL COMMENT '消息发送时间',
   `create_user_id` bigint(20) DEFAULT NULL COMMENT '创建用户',
   `create_time` datetime DEFAULT NULL COMMENT '创建时间',
   `update_time` datetime DEFAULT NULL COMMENT '更新时间',
   PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci ROW_FORMAT=DYNAMIC COMMENT='房间消息表';



-- ----------------------------
-- 第三方交互日志表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_third_party_logs`;
CREATE TABLE `mortals_xhx_third_party_logs` (
    `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '种类详情id',
    `room_id` bigint(20) DEFAULT NULL COMMENT '房间ID',
    `sender_id` bigint(20) DEFAULT NULL COMMENT '发送者用户ID',
    `third_party_action` varchar(32) DEFAULT 'create' COMMENT '第三方操作类型(create.创建，update.更新，delete.删除，sync.同步，other.其他)',
    `request_path` varchar(128) DEFAULT NULL COMMENT '第三方API请求地址',
    `request_message` varchar(1024) DEFAULT NULL COMMENT '第三方API请求代码',
    `response_code` varchar(32) DEFAULT NULL COMMENT '第三方API响应代码',
    `response_message` text DEFAULT NULL COMMENT '第三方API返回的消息',
    `send_time` datetime DEFAULT NULL COMMENT '消息发送时间',
    `create_user_id` bigint(20) DEFAULT NULL COMMENT '创建用户',
    `create_time` datetime DEFAULT NULL COMMENT '创建时间',
    `update_time` datetime DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci ROW_FORMAT=DYNAMIC COMMENT='第三方交互日志表';