package com.mortals.xhx.base.system.user.model;

import com.mortals.framework.ap.SysConstains;
import com.mortals.framework.service.IUser;
import com.mortals.xhx.base.system.user.model.vo.UserVo;
import lombok.Data;

import java.util.Date;
/**
 * 用户信息业务实体对象
 *
 * @author zxfei
 * @date 2024-12-23
 */
@Data
public class UserEntity extends UserVo implements IUser {
    private static final long serialVersionUID = 1L;

    /**
     * 登录名
     */
    private String loginName;
    /**
     * 登录密码，使用md5双次加密
     */
    private String loginPwd;
    /**
     * 登录限制地址，多个IP地址用逗号分隔，可以使用IP段匹配，如：172.17.*非空：则只能该值内的IP可以登录
     */
    private String loginLimitAddress;
    /**
     * 用户名
     */
    private String realName;
    /**
     * 用户手机号
     */
    private String mobile;
    /**
     * 用户联系电话
     */
    private String phone;
    /**
     * 用户邮箱
     */
    private String email;
    /**
     * QQ号码
     */
    private String qq;
    /**
     * 用户类型(0.系统用户,1.普通用户,2.工作人员)
     */
    private Integer userType;
    /**
     * 所属站点id,多个逗号分隔
     */
    private String siteIds;
    /**
     * 所属区域code,多个逗号分隔
     */
    private String areaCodes;
    /**
     * 用户状态(0.停用，1.正常，2.冻结，3.销户，4.离职)
     */
    private Integer status;
    /**
     * 创建用户名称
     */
    private String createUserName;
    /**
     * 最后一次登录时间
     */
    private Date lastLoginTime;
    /**
     * 最后一次登录地址
     */
    private String lastLoginAddress;
    /**
     * 第三方平台的用户唯一标识
     */
    private String thirdPartyUserId;
    /**
     * 第三方平台用户的认证令牌
     */
    private String thirdPartyToken;
    @Override
    public int hashCode() {
        return this.getId().hashCode();
    }
    @Override
    public boolean equals(Object obj) {
        if (obj == null) return false;
        if (obj instanceof UserEntity) {
            UserEntity tmp = (UserEntity) obj;
            if (this.getId() == tmp.getId()) {
                return true;
            }
        }
        return false;
    }

    public void initAttrValue(){
        this.loginName = "";
        this.loginPwd = "";
        this.loginLimitAddress = "";
        this.realName = "";
        this.mobile = "";
        this.phone = "";
        this.email = "";
        this.qq = "";
        this.userType = 0;
        this.siteIds = "";
        this.areaCodes = "";
        this.status = 0;
        this.createUserName = "";
        this.lastLoginTime = null;
        this.lastLoginAddress = "";
        this.thirdPartyUserId = "";
        this.thirdPartyToken = "";
    }

    @Override
    public Long getDeptId() {
        return null;
    }

    @Override
    public String getDeptName() {
        return null;
    }

    @Override
    public Long getCustomerId() {
        return null;
    }

    @Override
    public Long getSiteId() {
        return null;
    }

    @Override
    public Long getCustomerJoinId() {
        return null;
    }

    @Override
    public String getCustomerNum() {
        return null;
    }

    @Override
    public boolean isAdmin() {
        return super.getId() == null ? false : super.getId().longValue() == SysConstains.ADMIN_ID;
    }

    @Override
    public boolean isSystemUser() {
        return userType != null && userType.intValue() == 0;
    }

    @Override
    public boolean isManager() {
        return false;
    }
}