package com.mortals.xhx.daemon.applicationservice;

import com.mortals.framework.springcloud.service.IApplicationStartedService;
import com.mortals.xhx.base.system.message.RabbitMessageService;
import com.mortals.xhx.base.system.user.model.UserQuery;
import com.mortals.xhx.base.system.user.service.UserService;
import com.mortals.xhx.common.code.UserTypeEnum;
import com.mortals.xhx.common.key.Constant;
import com.mortals.xhx.common.key.QueueKey;
import com.mortals.xhx.module.workman.service.WorkmanService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.rabbit.listener.DirectMessageListenerContainer;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

/**
 * 初始化设备消费者注册
 *
 * @author: zxfei
 * @date: 2022/9/2 9:17
 */
@Component
@Slf4j
public class WorkmanRegisterService implements IApplicationStartedService {


    @Autowired
    private DirectMessageListenerContainer container;
    @Autowired
    private RabbitMessageService messageProducer;
    @Autowired
    private WorkmanService workmanService;
    @Autowired
    private UserService userService;

    @Value("${deviceUpdateComsumerIp:}")
    public String deviceUpdateComsumerIp;

    @Override
    public void start() {
        log.info("服务端消息队列初始化服务开始..");
   /*     String[] queues = workmanService.find(new WorkmanEntity()).stream().map(item -> {
            String workmanQueue = Constant.WORKMAN_TOPIC + item.getNumber();
            messageProducer.queueAddAndBinds(QueueKey.DEFAULT_EXCHANGE, workmanQueue, workmanQueue);
            return workmanQueue;
        }).toArray(String[]::new);
*/


        UserQuery userQuery = new UserQuery();
        userQuery.setUserType(UserTypeEnum.工作人员.getValue());
        String[] queues = userService.find(userQuery).stream().map(item -> {
            String customerQueue = Constant.CUSTOMER_TOPIC + item.getId();
            messageProducer.queueAddAndBinds(QueueKey.DEFAULT_EXCHANGE, customerQueue, customerQueue);
            return customerQueue;
        }).toArray(String[]::new);


/*        log.info("服务端注册工作人员队列服务开始..");
        container.addQueueNames(queues);
        container.start();*/

        userQuery = new UserQuery();
        userQuery.setUserType(UserTypeEnum.普通用户.getValue());
        queues = userService.find(userQuery).stream().map(item -> {
            String customerQueue = Constant.CUSTOMER_TOPIC + item.getId();
            messageProducer.queueAddAndBinds(QueueKey.DEFAULT_EXCHANGE, customerQueue, customerQueue);
            return customerQueue;
        }).toArray(String[]::new);

/*        log.info("服务端注册普通人员队列服务开始..");
        container.addQueueNames(queues);
        container.start();*/
    }

    @Override
    public void stop() {
        log.info("停止服务..");
        container.stop();

    }

    @Override
    public int getOrder() {
        return 10;
    }


}
