package com.mortals.xhx.module.room.service.impl;

import com.mortals.framework.model.PageInfo;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.xhx.module.room.dao.RoomDao;
import com.mortals.xhx.module.room.model.RoomEntity;
import com.mortals.xhx.module.room.service.RoomService;
import org.springframework.beans.factory.annotation.Autowired;
import com.mortals.xhx.module.room.model.RoomMemberEntity;
import com.mortals.xhx.module.room.model.RoomMemberQuery;
import com.mortals.xhx.module.room.service.RoomMemberService;
import org.springframework.util.ObjectUtils;
import java.util.Date;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import lombok.extern.slf4j.Slf4j;
/**
* RoomService
* 房间 service实现
*
* @author zxfei
* @date 2024-12-17
*/
@Service("roomService")
@Slf4j
public class RoomServiceImpl extends AbstractCRUDServiceImpl<RoomDao, RoomEntity, Long> implements RoomService {
    @Autowired
    private RoomMemberService roomMemberService;

    @Override
    protected void findAfter(RoomEntity params, PageInfo pageInfo, Context context, List<RoomEntity> list) throws AppException {
        fillSubData(list);
        super.findAfter(params,pageInfo, context, list);
    }
    @Override
    protected void findAfter(RoomEntity params, Context context, List<RoomEntity> list) throws AppException {
        fillSubData(list);
        super.findAfter(params, context, list);
    }

    private void fillSubData(List<RoomEntity> list) {
        List<Long> idList = list.stream().map(i -> i.getId()).collect(Collectors.toList());
        if(ObjectUtils.isEmpty(idList))return;
        Map<Long, List<RoomMemberEntity>> roomMemberListMap = roomMemberService
                .find(new RoomMemberQuery().roomIdList(idList)).parallelStream()
                .collect(Collectors.groupingBy(RoomMemberEntity::getRoomId));
        list.forEach(item -> item.setRoomMemberList(roomMemberListMap.get(item.getId())));
    }

    
    @Override
    protected void saveAfter(RoomEntity entity, Context context) throws AppException {
        if(!ObjectUtils.isEmpty(entity.getRoomMemberList())){
            entity.getRoomMemberList().stream().peek(item->{
                item.setRoomId(entity.getId());
                item.setCreateUserId(this.getContextUserId(context));
                item.setCreateTime(new Date());
            }).count();
            roomMemberService.save(entity.getRoomMemberList());
        }
        super.saveAfter(entity, context);
    }

    @Override
    protected void updateAfter(RoomEntity entity, Context context) throws AppException {
        if(!ObjectUtils.isEmpty(entity.getRoomMemberList())){
            Long[] roomMemberIds = roomMemberService.find(new RoomMemberQuery().roomId(entity.getId())).stream().map(RoomMemberEntity::getId).toArray(Long[]::new);
            roomMemberService.remove(roomMemberIds,context);
            entity.getRoomMemberList().stream().peek(item ->{
                item.setRoomId(entity.getId());
                item.setCreateUserId(this.getContextUserId(context));
                item.setCreateTime(new Date());
                item.setUpdateUserId(this.getContextUserId(context));
                item.setUpdateTime(new Date());
            }).count();
            roomMemberService.save(entity.getRoomMemberList());
        }
        super.updateAfter(entity, context);
    }

    @Override
    protected void removeAfter(Long[] ids, Context context, int result) throws AppException {
        List<RoomMemberEntity> roomMemberlist = roomMemberService.find(new RoomMemberQuery().roomIdList(Arrays.asList(ids)));
        roomMemberService.removeList(roomMemberlist,context);
        super.removeAfter(ids, context, result);
    }
}