package com.mortals.xhx.module.workman.web;

import cn.hutool.core.codec.Base64;
import cn.hutool.core.util.StrUtil;
import cn.hutool.extra.pinyin.PinyinUtil;
import com.alibaba.fastjson.JSONObject;
import com.mortals.framework.annotation.UnAuth;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.base.system.param.service.ParamService;
import com.mortals.xhx.base.system.upload.service.UploadService;
import com.mortals.xhx.common.code.YesNoEnum;
import com.mortals.xhx.module.workman.model.WorkmanEntity;
import com.mortals.xhx.module.workman.service.WorkmanService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import java.util.Map;

/**
 * 工作人员
 *
 * @author zxfei
 * @date 2022-01-20
 */
@RestController
@RequestMapping("workman")
@Slf4j
public class WorkmanController extends BaseCRUDJsonBodyMappingController<WorkmanService, WorkmanEntity, Long> {

    @Autowired
    private ParamService paramService;



    public WorkmanController() {
        super.setModuleDesc("工作人员");
    }


    @Override
    protected void init(Map<String, Object> model, Context context) {
        this.addDict(model, "politicalstatus", paramService.getParamBySecondOrganize("Workman", "politicalstatus"));
        this.addDict(model, "dangyuan", paramService.getParamBySecondOrganize("Workman", "dangyuan"));
        this.addDict(model, "starlevel", paramService.getParamBySecondOrganize("Workman", "starlevel"));


        super.init(model, context);
    }


    /**
     * @param query
     * @param model
     * @param context
     * @throws AppException
     */
    @Override
    protected void doListBefore(WorkmanEntity query, Map<String, Object> model, Context context) throws AppException {
        if (!ObjectUtils.isEmpty(query)) {
            query.setDeleted(YesNoEnum.NO.getValue());
        }
        super.doListBefore(query, model, context);
    }

    /**
     *
     */
    @Override
    @UnAuth
    public void downloadTemplate() {
        super.downloadTemplate();
    }




    @RequestMapping(value = "change/password", method = RequestMethod.POST)
    @UnAuth
    public String changePassword(@RequestBody WorkmanEntity query) {
        JSONObject ret = new JSONObject();
        try {
            //校验密码复杂度 todo
/*            if (!checkPwdComplexity(query.getNewPwd())) {
                PasswdStrength.check(query.getNewPwd())
            }*/
            boolean bool = service.updateUserPwd(query.getLoginName(), query.getNewPwd());
            if (bool) {
                ret.put(KEY_RESULT_CODE, VALUE_RESULT_SUCCESS);
                ret.put(KEY_RESULT_MSG, "密码修改成功！");
            } else {
                throw new AppException("账户密码修改失败！");
            }

        } catch (Exception e) {
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
        }
        return ret.toJSONString();
    }


    public static void main(String[] args) {

        System.out.println(StrUtil.cleanBlank(PinyinUtil.getPinyin("张 三", "")));

        System.out.println(Base64.encode("[]"));

    }

}